# TeselaGen Python Tools.

This package includes some Python tools to use in combination with TeselaGen platform.
These tools includes _TeselaGen Python API Client_ 

This package runs on Python 3.6 and above.

**NOTE :** All the following commands are supposed to be run on the `base` directory, unless specified.

## Library Installation
This library contains the TeselaGen Python API Client.

To install it locally,

1. By using PIP

    Use `pip install teselagen`


